@@ -21,7 +21,7 @@ class dstat_plugin(dstat):
 
             self.gl = vmguestlib.VMGuestLib()
         except:
-            raise Exception, 'Needs python-vmguestlib module'
+            raise Exception('Needs python-vmguestlib module')
 
     def extract(self):
         self.gl.UpdateInfo()
@@ -35,4 +35,4 @@ class dstat_plugin(dstat):
         if step == op.delay:
             self.set1.update(self.set2)
 
-# vim:ts=4:sw=4
\ No newline at end of file
+# vim:ts=4:sw=4
